<?php
/** Don't load directly */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'foxiz_register_options_ads' ) ) {
	/**
	 * @return array
	 * global logo
	 */
	function foxiz_register_options_ads() {
		return array(
			'id'     => 'foxiz_config_section_ads',
			'title'  => esc_html__( 'Ads', 'foxiz' ),
			'desc'   => esc_html__( 'Select ad settings for your website.', 'foxiz' ),
			'icon'   => 'el el-usd',
			'fields' => array(
				array(
					'id'    => 'info_advertising',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'This section supports ads in the top header website and inner single content. For other ad spots, please read the theme documentation for further info.', 'foxiz' ),
				),
				array(
					'id'     => 'section_start_ad_top',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Top Site Advert', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'       => 'ad_top_type',
					'title'    => esc_html__( 'Ad Type', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a ad type for displaying in the top of the website.', 'foxiz' ),
					'type'     => 'select',
					'options'  => array(
						'1' => esc_html__( 'Script', 'foxiz' ),
						'0' => esc_html__( 'Custom Image', 'foxiz' ),
					),
					'default'  => '1'
				),
				array(
					'id'       => 'ad_top_code',
					'title'    => esc_html__( 'Script - Ad/Adsense Code', 'foxiz' ),
					'subtitle' => esc_html__( 'Input your ad script code.', 'foxiz' ),
					'type'     => 'textarea',
					'default'  => ''
				),
				array(
					'id'       => 'ad_top_size',
					'title'    => esc_html__( 'Script - Ad Size', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a custom size for this ad if you use asynchronous adsense.', 'foxiz' ),
					'type'     => 'select',
					'options'  => array(
						'0' => esc_html__( 'Do not Override', 'foxiz' ),
						'1' => esc_html__( 'Custom Size Below', 'foxiz' )
					),
					'default'  => '0'
				),
				array(
					'id'       => 'ad_top_desktop_size',
					'title'    => esc_html__( 'Script - Size on Desktop', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a size on the desktop device.', 'foxiz' ),
					'type'     => 'select',
					'options'  => foxiz_ad_size_dropdown(),
					'default'  => '1'
				),
				array(
					'id'       => 'ad_top_tablet_size',
					'title'    => esc_html__( 'Script - Size on Tablet', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a size on the tablet device.', 'foxiz' ),
					'type'     => 'select',
					'options'  => foxiz_ad_size_dropdown(),
					'default'  => '2'
				),
				array(
					'id'       => 'ad_top_mobile_size',
					'title'    => esc_html__( 'Script - Size on Mobile', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a size on the mobile device.', 'foxiz' ),
					'type'     => 'select',
					'options'  => foxiz_ad_size_dropdown(),
					'default'  => '3'
				),
				array(
					'id'       => 'ad_top_image',
					'title'    => esc_html__( 'Custom Image - Ad Image', 'foxiz' ),
					'subtitle' => esc_html__( 'Upload your ad image.', 'foxiz' ),
					'type'     => 'media',
					'default'  => ''
				),
				array(
					'id'       => 'ad_top_dark_image',
					'title'    => esc_html__( 'Custom Image - Dark Mode Ad Image', 'foxiz' ),
					'subtitle' => esc_html__( 'Upload your ad image in the dark mode.', 'foxiz' ),
					'type'     => 'media',
					'default'  => ''
				),
				array(
					'id'       => 'ad_top_destination',
					'title'    => esc_html__( 'Custom Image - Ad Destination', 'foxiz' ),
					'subtitle' => esc_html__( 'Input your ad destination URL.', 'foxiz' ),
					'type'     => 'text',
					'default'  => '#'
				),
				array(
					'id'       => 'ad_top_width',
					'title'    => esc_html__( 'Custom Image - Max Width', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a max width value (in px) for your ad image, leave blank set full size.', 'foxiz' ),
					'type'     => 'text',
					'default'  => ''
				),
				array(
					'id'          => 'ad_top_bg',
					'title'       => esc_html__( 'Section Background', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a background for this ad section.', 'foxiz' ),
					'type'        => 'color',
					'transparent' => false,
					'default'     => ''
				),
				array(
					'id'          => 'ad_top_dark_bg',
					'title'       => esc_html__( 'Dark Mode - Section Background', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a background for this ad section in the dark mode.', 'foxiz' ),
					'type'        => 'color',
					'transparent' => false,
					'default'     => ''
				),
				array(
					'id'       => 'ad_top_spacing',
					'title'    => esc_html__( 'Spacing', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a top and bottom spacing for the advert.', 'foxiz' ),
					'type'     => 'select',
					'options'  => array(
						'0' => esc_html__( '15px', 'foxiz' ),
						'1' => esc_html__( 'No spacing', 'foxiz' )
					),
					'default'  => '0'
				),
				array(
					'id'     => 'section_end_ad_top',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}
