<?php
/** Don't load directly */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'foxiz_register_options_header' ) ) {
	/**
	 * @return array
	 * header settings
	 */
	function foxiz_register_options_header() {
		return array(
			'id'    => 'foxiz_config_section_header',
			'title' => esc_html__( 'Header', 'foxiz' ),
			'desc'  => esc_html__( 'Select options for your website header.', 'foxiz' ),
			'icon'  => 'el el-th'
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_general' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_general() {

		return array(
			'id'         => 'foxiz_config_section_header_general',
			'title'      => esc_html__( 'General', 'foxiz' ),
			'icon'       => 'el el-cog',
			'subsection' => true,
			'desc'       => esc_html__( 'Select the style and other settings for your website header.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'     => 'section_start_header_style',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Header Style', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'          => 'header_style',
					'type'        => 'select',
					'title'       => esc_html__( 'Global Header Style', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select the global header style for your website header.', 'foxiz' ),
					'options'     => foxiz_config_header_style(),
					'description' => esc_html__( 'Please select setting panel corresponding to the layout you choose for setting up background, color and other settings.', 'foxiz' ),
					'default'     => '1'
				),
				array(
					'id'     => 'section_end_header_style',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_header_sticky',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Sticky Menu', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'       => 'sticky',
					'type'     => 'switch',
					'title'    => esc_html__( 'Sticky Menu', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the sticky feature for the main menu bar.', 'foxiz' ),
					'default'  => '0'
				),
				array(
					'id'       => 'smart_sticky',
					'type'     => 'switch',
					'title'    => esc_html__( 'Smart Sticky', 'foxiz' ),
					'subtitle' => esc_html__( 'Only stick the main menu when scrolling up.', 'foxiz' ),
					'default'  => '0'
				),
				array(
					'id'     => 'section_end_header_sticky',
					'type'   => 'section',
					'class'  => 'no-border ruby-section-end',
					'indent' => false
				)
			)
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_more' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_more() {

		return array(
			'id'         => 'foxiz_config_section_header_more',
			'title'      => esc_html__( 'More Menu Item', 'foxiz' ),
			'icon'       => 'el el-braille',
			'subsection' => true,
			'desc'       => esc_html__( 'Select options for the more menu and enable/disable it for each header style.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'    => 'info_more_section',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'To add column widgets, navigate to "Dashboard > Appearance > Widgets > More Menu Section". Please read the documentation for further information.', 'foxiz' ),
				),
				array(
					'id'          => 'more_column',
					'type'        => 'select',
					'title'       => esc_html__( 'Columns per Row', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select columns per row for this section.', 'foxiz' ),
					'description' => esc_html__( 'Each widget is added in "Appearance >Widgets > More Menu Section" will be corresponding to a column.', 'foxiz' ),
					'options'     => array(
						'2' => esc_html__( '2 Columns', 'foxiz' ),
						'3' => esc_html__( '3 Columns', 'foxiz' ),
						'4' => esc_html__( '4 Columns', 'foxiz' ),
						'5' => esc_html__( '5 Columns', 'foxiz' )
					),
					'default'     => '3'
				),
				array(
					'id'       => 'more_footer_menu',
					'type'     => 'select',
					'options'  => foxiz_config_menu_slug(),
					'title'    => esc_html__( 'Footer Menu', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a footer menu to display at the bottom of this section.', 'foxiz' ),
					'default'  => ''
				),
				array(
					'id'       => 'more_footer_copyright',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Footer Copyright', 'foxiz' ),
					'subtitle' => esc_html__( 'Input the footer copyright text to display at the bottom of this section, allow raw HTML.', 'foxiz' ),
					'default'  => ''
				)
			)
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_search' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_search() {
		return array(
			'id'         => 'foxiz_config_section_header_search',
			'title'      => esc_html__( 'Header Search', 'foxiz' ),
			'icon'       => 'el el-search',
			'subsection' => true,
			'desc'       => esc_html__( 'Select settings for search form to display in the website header.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'    => 'info_search_placeholder',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'To edit the placeholder text of the search form, navigate to "Theme Options > General > Search Placeholder".', 'foxiz' ),
				),
				array(
					'id'       => 'header_search_icon',
					'type'     => 'switch',
					'title'    => esc_html__( 'Header Search Icon', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the search icon in the header.', 'foxiz' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'          => 'header_search_mode',
					'type'        => 'select',
					'title'       => esc_html__( 'Toggle Mode', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select mode for the search button when clicking on.', 'foxiz' ),
					'description' => esc_html__( 'Ensure the option "More Menu - Search Form" is enabled when you select the "More Menu Triggered" option.', 'foxiz' ),
					'options'     => array(
						'search' => esc_html__( 'Standard Search Form', 'foxiz' ),
						'more'   => esc_html__( 'More Menu Triggered', 'foxiz' )
					),
					'default'     => 'search'
				),
				array(
					'id'       => 'more_search',
					'type'     => 'switch',
					'title'    => esc_html__( 'More Menu - Search Form', 'foxiz' ),
					'subtitle' => esc_html__( 'Show search form at the top of the more section.', 'foxiz' ),
					'default'  => 1
				),
				array(
					'id'       => 'mobile_search',
					'type'     => 'switch',
					'title'    => esc_html__( 'Mobile Header - Search', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable search icon and form on the mobile header.', 'foxiz' ),
					'default'  => 1
				),
				array(
					'id'       => 'header_search_heading',
					'type'     => 'text',
					'title'    => esc_html__( 'Search Heading', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a heading for displaying above the search form.', 'foxiz' ),
					'default'  => esc_html__( 'Search', 'foxiz' )
				),
				array(
					'id'       => 'header_search_custom_icon',
					'type'     => 'media',
					'url'      => true,
					'preview'  => true,
					'title'    => esc_html__( 'Custom Search SVG', 'foxiz' ),
					'subtitle' => esc_html__( 'Override default search icon with SVG.', 'foxiz' ),
				),
			)
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_notification' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_notification() {
		return array(
			'id'         => 'foxiz_config_section_header_notification',
			'title'      => esc_html__( 'Notification', 'foxiz' ),
			'icon'       => 'el el-bell',
			'subsection' => true,
			'desc'       => esc_html__( 'This section will show the user bookmark list and latest blog listing.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'       => 'header_notification',
					'type'     => 'switch',
					'title'    => esc_html__( 'Notification Section', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the notification section on the header.', 'foxiz' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'header_notification_url',
					'type'     => 'text',
					'title'    => esc_html__( 'Destination Link', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a destination URL for the notification panel.', 'foxiz' ),
					'default'  => '#'
				),
				array(
					'id'       => 'header_notification_scheme',
					'type'     => 'select',
					'title'    => esc_html__( 'Text Color Scheme', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a text color scheme to fit with the sub menu background.', 'foxiz' ),
					'options'  => array(
						'0' => esc_html__( 'Default (Dark Text)', 'foxiz' ),
						'1' => esc_html__( 'Light Text', 'foxiz' )
					),
					'default'  => 0
				),
			)
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_mobile' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_mobile() {
		return array(
			'id'         => 'foxiz_config_section_header_mobile',
			'title'      => esc_html__( 'Mobile Header', 'foxiz' ),
			'icon'       => 'el el-iphone-home',
			'subsection' => true,
			'desc'       => esc_html__( 'The settings below apply to the mobile header.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'    => 'info_mobile_navbar_typo',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'To edit this section typography, navigate to "Typography > Menu > Mobile Menu Settings".', 'foxiz' ),
				),
				array(
					'id'     => 'section_start_mh_layout',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Layout Setting', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'       => 'mh_layout',
					'type'     => 'select',
					'title'    => esc_html__( 'Mobile Header Layout', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a layout for the mobile header.', 'foxiz' ),
					'options'  => array(
						'0' => esc_html__( 'Left Logo', 'foxiz' ),
						'1' => esc_html__( 'Center Logo', 'foxiz' ),
					),
					'default'  => 0
				),
				array(
					'id'     => 'section_end_mh_layout',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_mobile_collapse',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Collapse Section', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'    => 'info_mobile_socials_list',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'To manage the social profile URLs, navigate to "Social Profiles".', 'foxiz' ),
				),
				array(
					'id'       => 'mobile_social',
					'type'     => 'switch',
					'title'    => esc_html__( 'Socials List', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the socials list.', 'foxiz' ),
					'default'  => 1
				),
				array(
					'id'       => 'mobile_footer_menu',
					'type'     => 'select',
					'options'  => foxiz_config_menu_slug(),
					'title'    => esc_html__( 'Footer Menu', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a footer menu to display at the bottom of this section.', 'foxiz' ),
					'default'  => ''
				),
				array(
					'id'       => 'mobile_copyright',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Footer Copyright', 'foxiz' ),
					'subtitle' => esc_html__( 'Input the footer copyright text to display at the bottom of this section, allow raw HTML.', 'foxiz' ),
					'default'  => ''
				),
				array(
					'id'     => 'section_end_mobile_collapse',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_mh_colors',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Header Colors', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'          => 'mobile_background',
					'type'        => 'color_gradient',
					'title'       => esc_html__( 'Background Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a background color for the mobile navigation bar, use the option "to" to set gradient background.', 'foxiz' ),
					'validate'    => 'color',
					'transparent' => false,
					'default'     => array(
						'from' => '',
						'to'   => '',
					),
				),
				array(
					'id'          => 'mobile_color',
					'title'       => esc_html__( 'Text Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a text color for displaying in the mobile menu.', 'foxiz' ),
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
				),
				array(
					'id'          => 'mobile_sub_background',
					'type'        => 'color_gradient',
					'title'       => esc_html__( 'Collapse - Background Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a background color for the collapse section.', 'foxiz' ),
					'validate'    => 'color',
					'transparent' => false,
					'default'     => array(
						'from' => '',
						'to'   => '',
					),
				),
				array(
					'id'          => 'mobile_sub_color',
					'title'       => esc_html__( 'Collapse - Text Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a text color for displaying in the collapse section.', 'foxiz' ),
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
				),
				array(
					'id'     => 'section_end_mh_colors',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_mh_dark_colors',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Dark Mode Colors', 'foxiz' ),
					'indent' => true
				),
				array(
					'id'          => 'dark_mobile_background',
					'type'        => 'color_gradient',
					'title'       => esc_html__( 'Background Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a background color for the mobile navigation bar in the dark mode.', 'foxiz' ),
					'validate'    => 'color',
					'transparent' => false,
					'default'     => array(
						'from' => '',
						'to'   => '',
					),
				),
				array(
					'id'          => 'dark_mobile_color',
					'title'       => esc_html__( 'Text Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a background color for the collapse section in the dark mode.', 'foxiz' ),
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
				),
				array(
					'id'          => 'dark_mobile_sub_background',
					'type'        => 'color_gradient',
					'title'       => esc_html__( 'Collapse - Background Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a text color for displaying in the collapse section in the dark mode.', 'foxiz' ),
					'validate'    => 'color',
					'transparent' => false,
					'default'     => array(
						'from' => '',
						'to'   => '',
					),
				),
				array(
					'id'          => 'dark_mobile_sub_color',
					'title'       => esc_html__( 'Collapse - Text Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select a text color for sub-level menus in the dark mode.', 'foxiz' ),
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
				),
				array(
					'id'     => 'section_end_mh_dark_colors',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				)
			)
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_login' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_login() {
		return array(
			'id'         => 'foxiz_config_section_header_login',
			'title'      => esc_html__( 'Popup Sign In', 'foxiz' ),
			'icon'       => 'el el-user',
			'subsection' => true,
			'desc'       => esc_html__( 'Select settings for the popup sign in form.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'       => 'header_login_icon',
					'type'     => 'switch',
					'title'    => esc_html__( 'Sign In', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the sign in button on the header.', 'foxiz' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'mobile_login',
					'type'     => 'switch',
					'title'    => esc_html__( 'Mobile Header - Sign In', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the sign in button on the mobile header.', 'foxiz' ),
					'default'  => 1
				),
				array(
					'id'       => 'header_login_layout',
					'type'     => 'select',
					'title'    => esc_html__( 'Trigger Button Layout', 'foxiz' ),
					'subtitle' => esc_html__( 'Select a layout for the sign in trigger button.', 'foxiz' ),
					'options'  => array(
						'0' => esc_html__( 'Icon', 'foxiz' ),
						'1' => esc_html__( 'Text Button', 'foxiz' )
					),
					'default'  => 0
				),
				array(
					'id'       => 'header_login_heading',
					'type'     => 'text',
					'title'    => esc_html__( 'Form Heading', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a heading for the login form.', 'foxiz' ),
					'default'  => esc_html__( 'Welcome Back!', 'foxiz' )
				),
				array(
					'id'       => 'header_login_description',
					'type'     => 'text',
					'title'    => esc_html__( 'Form Description', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a description for the login form. Leave blank to set as the default.', 'foxiz' ),
					'default'  => esc_html__( 'Sign in to your account', 'foxiz' )
				),
				array(
					'id'       => 'header_login_logo',
					'type'     => 'media',
					'title'    => esc_html__( 'Form Logo', 'foxiz' ),
					'subtitle' => esc_html__( 'Adding a custom logo for the login form. Leave blank to set as the default.', 'foxiz' ),
					'url'      => true,
					'preview'  => true,
				),
				array(
					'id'       => 'header_login_dark_logo',
					'type'     => 'media',
					'title'    => esc_html__( 'Dark Mode - Form Logo', 'foxiz' ),
					'subtitle' => esc_html__( 'Adding a custom logo for the login form in the dark mode.', 'foxiz' ),
					'url'      => true,
					'preview'  => true,
				),
				array(
					'id'       => 'header_login_redirect',
					'type'     => 'text',
					'title'    => esc_html__( 'Redirect URL', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a redirect URL when the user logged in.', 'foxiz' ),
					'default'  => '',
				),
				array(
					'id'       => 'header_login_menu',
					'type'     => 'select',
					'title'    => esc_html__( 'User Dashboard Menu', 'foxiz' ),
					'subtitle' => esc_html__( 'Assign a menu for displaying when hovering on the login icon if user logged.', 'foxiz' ),
					'options'  => foxiz_config_menu_slug(),
					'default'  => '',
				),
				array(
					'id'       => 'header_login_register',
					'type'     => 'text',
					'title'    => esc_html__( 'Custom Register URL', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a custom register URL if have.', 'foxiz' ),
					'default'  => '',
				),
				array(
					'id'       => 'header_login_forget',
					'type'     => 'text',
					'title'    => esc_html__( 'Custom Forget Password URL', 'foxiz' ),
					'subtitle' => esc_html__( 'Input a custom forget password URL if have.', 'foxiz' ),
					'default'  => '',
				),
			)
		);
	}
}

if ( ! function_exists( 'foxiz_register_options_header_alert' ) ) {
	/**
	 * @return array
	 */
	function foxiz_register_options_header_alert() {
		return array(
			'id'         => 'foxiz_config_section_header_alert',
			'title'      => esc_html__( 'Alert Bar', 'foxiz' ),
			'icon'       => 'el el-bell',
			'subsection' => true,
			'desc'       => esc_html__( 'This section will show a small alert or event at the bottom of the navigation.', 'foxiz' ),
			'fields'     => array(
				array(
					'id'       => 'alert_bar',
					'type'     => 'switch',
					'title'    => esc_html__( 'Alert Bar', 'foxiz' ),
					'subtitle' => esc_html__( 'Enable or disable the alert bar below the header. This option will be overridden by the setting in individual post/page.', 'foxiz' ),
					'default'  => false,
				),
				array(
					'id'       => 'alert_home',
					'type'     => 'switch',
					'title'    => esc_html__( 'Only Homepage', 'foxiz' ),
					'subtitle' => esc_html__( 'Only show the bar in the homepage.', 'foxiz' ),
					'switch'   => true,
					'default'  => true
				),
				array(
					'id'       => 'alert_content',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Alert Content', 'foxiz' ),
					'subtitle' => esc_html__( 'Input your alert content to show.', 'foxiz' ),
					'default'  => ''
				),
				array(
					'id'       => 'alert_url',
					'type'     => 'text',
					'title'    => esc_html__( 'Alert URL', 'foxiz' ),
					'subtitle' => esc_html__( 'Input your alert URL.', 'foxiz' ),
					'default'  => '#'
				),
				array(
					'id'          => 'alert_bg',
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
					'title'       => esc_html__( 'Background Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select background color for the bar.', 'foxiz' )
				),
				array(
					'id'          => 'alert_color',
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
					'title'       => esc_html__( 'Text Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select text color for the bar.', 'foxiz' )
				),
				array(
					'id'          => 'dark_alert_bg',
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
					'title'       => esc_html__( 'Dark Mode - Background Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select background color for the bar in the dark mode.', 'foxiz' ),
				),
				array(
					'id'          => 'dark_alert_color',
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
					'title'       => esc_html__( 'Dark Mode - Text Color', 'foxiz' ),
					'subtitle'    => esc_html__( 'Select text color for the bar in the dark mode.', 'foxiz' ),
				),
				array(
					'id'       => 'alert_sticky_hide',
					'title'    => esc_html__( 'Hide when Sticky', 'foxiz' ),
					'subtitle' => esc_html__( 'Hide this bar on the sticky navigation.', 'foxiz' ),
					'type'     => 'switch',
					'default'  => false
				),
			)
		);
	}
}